/* TimeZoneManager.h
 *
 * Copyright (C) 2004 by vhf interservice GmbH
 * Author:   Georg Fleischmann
 *
 * created:  2004-10-06
 * modified: 2004-10-06
 */

#ifndef VHF_H_TIMEZONEMANAGER
#define VHF_H_TIMEZONEMANAGER

#include <AppKit/AppKit.h>

/* notifications */
#define AstroTimeZoneChanged	@"AstroTimeZoneChanged"

@interface TimeZoneManager:NSObject
{
    id	timeZonePanel;
    id	timeZoneBrowser;

    NSMutableArray	*regions;	// regions
    NSMutableArray	*zones;		// the zones in a region
}

/* action methods */
- (void)showPanel:sender;

- (void)set:sender;

@end

#endif	// VHF_H_TIMEZONEMANAGER
